@@ -50,6 +50,8 @@ import org.apache.cxf.tools.common.ToolException;
 import org.apache.cxf.tools.common.model.DefaultValueWriter;
 import org.apache.cxf.tools.util.ClassCollector;
 import org.apache.cxf.tools.wsdlto.core.DataBindingProfile;
+import org.apache.xmlbeans.SchemaGlobalElement;
+import org.apache.xmlbeans.SchemaProperty;
 import org.apache.xmlbeans.SchemaType;
 import org.apache.xmlbeans.SchemaTypeLoader;
 import org.apache.xmlbeans.SchemaTypeSystem;
@@ -89,11 +91,13 @@ public class XMLBeansToolingDataBinding implements DataBindingProfile {
     }    
     
     SchemaTypeSystem typeSystem;
+    SchemaTypeLoader typeLoader;
     Map<String, String> sourcesToCopyMap = new HashMap<String, String>();
     List<XmlError> errors = new LinkedList<XmlError>();
     XmlErrorWatcher errorListener = new XmlErrorWatcher(errors);
     PathResourceLoader cpResourceLoader = new PathResourceLoader(CodeGenUtil.systemClasspath());
     StscState state;
+   
     
     public void initialize(ToolContext context) throws ToolException {
         context.put(ToolConstants.RUNTIME_DATABINDING_CLASS,
@@ -101,6 +105,7 @@ public class XMLBeansToolingDataBinding implements DataBindingProfile {
         
         String wsdl = (String)context.get(ToolConstants.CFG_WSDLURL);
         String catalog = (String)context.get(ToolConstants.CFG_CATALOG);
+              
         Object o = context.get(ToolConstants.CFG_BINDING);
         String bindingFiles[]; 
         if (o instanceof String) {
@@ -135,20 +140,42 @@ public class XMLBeansToolingDataBinding implements DataBindingProfile {
     public String getType(QName qn, boolean element) {
         String ret;
         if (element) {
-            ret = typeSystem.findElement(qn).getType().getFullJavaName();
+            SchemaType type = typeSystem.findDocumentType(qn);
+            if (type == null)  {
+                type = typeLoader.findDocumentType(qn);
+            }
+
+            ret = type.getFullJavaName();
             if (ret.contains("$")) {
                 ret = ret.substring(0, ret.indexOf('$'));
             }
             return ret;
         }
-        ret = typeSystem.findType(qn).getFullJavaName();
+
+        SchemaType type = typeSystem.findType(qn);
+        if (type == null) {
+            type = typeLoader.findType(qn);
+        }
+
+        ret = type.getFullJavaName();
         return ret.replace('$', '.');
     }
 
     public String getWrappedElementType(QName wrapperElement, QName item) {        
-        SchemaType st = typeSystem.findElement(wrapperElement).getType();
-        SchemaType partType = st.getElementProperty(item).getType();        
-        return XMLBeansSchemaTypeUtils.getNaturalJavaClassName(partType);        
+        SchemaGlobalElement elem = typeSystem.findElement(wrapperElement);
+
+        if (elem == null)  {
+            elem = typeLoader.findElement(wrapperElement);
+        }
+
+        SchemaType st = elem.getType();
+        SchemaProperty prop = st.getElementProperty(item);
+        SchemaType partType = prop.getType();
+        String s = XMLBeansSchemaTypeUtils.getNaturalJavaClassName(partType);
+        if (prop.extendsJavaArray()) {
+            s += "[]";
+        }
+        return s;
     }
 
     public void generate(ToolContext context) throws ToolException {
@@ -377,6 +404,9 @@ public class XMLBeansToolingDataBinding implements DataBindingProfile {
         params.setConfig(BindingConfigImpl.forConfigDocuments(cdocs, 
                                                               javaFiles.toArray(new File[javaFiles.size()]), 
                                                               CodeGenUtil.systemClasspath()));
+
+        typeLoader = loader;
+
         params.setLinkTo(linkTo);
         params.setOptions(opts);
         params.setErrorListener(errorListener);
