@@ -24,9 +24,27 @@ import java.lang.annotation.Retention;
 import java.lang.annotation.RetentionPolicy;
 import java.lang.annotation.Target;
 
+/**
+ * Annotate a JAX-RS function parameter to receive data from a multipart 'part'.
+ **/
 @Target({ElementType.PARAMETER, ElementType.FIELD, ElementType.METHOD })
 @Retention(RetentionPolicy.RUNTIME)
 public @interface Multipart {
+    /**
+     * The name of the MIME part to map to this parameter. The default is
+     * the unnamed default part.
+     **/
     String value() default "";
+    /**
+     * Select the part by MIME type. The default is to match any MIME type.
+     */
     String type() default "*/*";
+    /**
+     * How to handle a missing part. By default, if no part matches,
+     * the {@link org.apache.cxf.jaxrs.provider.MultipartProvider} 
+     * throws a {@link javax.ws.rs.WebApplicationException}
+     * with status 400. If this option is set to <strong>false</strong>,
+     * the parameter is set to <strong>null</strong>.
+     */
+    boolean errorIfMissing() default true; 
 }
