@@ -61,6 +61,28 @@ public class URITemplateTest extends Assert {
         assertEquals("123;123456", value);
     }
 
+    @Test
+    public void testMatchWithMatrixWithEmptyPath() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        boolean match = uriTemplate.match("/;a=b", values);
+        assertTrue(match);
+        String finalGroup = values.getFirst(URITemplate.FINAL_MATCH_GROUP);
+        assertEquals("/", finalGroup);
+    }
+    
+    @Test
+    public void testMatchWithMatrixWithEmptyPath2() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        boolean match = uriTemplate.match("/;a=b/b/c", values);
+        assertTrue(match);
+        String finalGroup = values.getFirst(URITemplate.FINAL_MATCH_GROUP);
+        assertEquals("/b/c", finalGroup);
+    }
+    
     @Test
     public void testMatchWithMatrixOnClearPath1() throws Exception {
         URITemplate uriTemplate = new URITemplate("/customers/{id}");
@@ -123,6 +145,16 @@ public class URITemplateTest extends Assert {
 
         assertTrue(uriTemplate.match("/customers;123456/123/orders;456/3", values));
     }
+    
+    @Test
+    public void testMatchWithMatrixOnClearPath5() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/customers");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        assertTrue(uriTemplate.match("/customers;a=b", values));
+        String finalGroup = values.getFirst(URITemplate.FINAL_MATCH_GROUP);
+        assertEquals("/", finalGroup);
+    }
 
     @Test
     public void testMatchBasicTwoParametersVariation1() throws Exception {
@@ -188,6 +220,17 @@ public class URITemplateTest extends Assert {
         String subResourcePath = values.getFirst(URITemplate.FINAL_MATCH_GROUP);
         assertEquals("/chapter/1", subResourcePath);
     }
+    
+    @Test
+    public void testURITemplateWithSubResourceVariation4() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        boolean match = uriTemplate.match("/books/123/chapter/1", values);
+        assertTrue(match);
+        String subResourcePath = values.getFirst(URITemplate.FINAL_MATCH_GROUP);
+        assertEquals("/books/123/chapter/1", subResourcePath);
+    }
 
     @Test
     public void testBasicCustomExpression() throws Exception {
@@ -250,7 +293,64 @@ public class URITemplateTest extends Assert {
         assertFalse(uriTemplate.match("/books/acdb", values));
 
     }
+    
+    @Test
+    public void testEscapingWildCard() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/books/a*");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
 
+        assertTrue(uriTemplate.match("/books/a*", values));
+        assertFalse(uriTemplate.match("/books/a", values));
+        assertFalse(uriTemplate.match("/books/ac", values));
+    }
+    
+    @Test
+    public void testValueWithLiteralPlus() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/books/ab+");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        assertTrue(uriTemplate.match("/books/ab+", values));
+        assertFalse(uriTemplate.match("/books/abb", values));
+        assertFalse(uriTemplate.match("/books/ab", values));
+        assertFalse(uriTemplate.match("/books/a", values));
+    }
+    
+    @Test
+    public void testValueWithManyLiteralPluses() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/books/ab+++++");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        assertTrue(uriTemplate.match("/books/ab+++++", values));
+        assertFalse(uriTemplate.match("/books/ab++++++", values));
+        assertFalse(uriTemplate.match("/books/ab++++", values));
+        assertFalse(uriTemplate.match("/books/ab+++", values));
+        assertFalse(uriTemplate.match("/books/ab++", values));
+        assertFalse(uriTemplate.match("/books/ab+", values));
+        assertFalse(uriTemplate.match("/books/ab", values));
+        assertFalse(uriTemplate.match("/books/a", values));
+    }
+
+    @Test
+    public void testValueWithRegExPlus() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/books/{regex:ab+\\+}");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        assertTrue(uriTemplate.match("/books/ab+", values));
+        assertFalse(uriTemplate.match("/books/abb", values));
+        assertFalse(uriTemplate.match("/books/abb", values));
+        assertFalse(uriTemplate.match("/books/abc", values));
+        assertFalse(uriTemplate.match("/books/a", values));
+    }
+    
+    @Test
+    public void testEncodedSpace() throws Exception {
+        URITemplate uriTemplate = new URITemplate("/1 2/%203");
+        MultivaluedMap<String, String> values = new MetadataMap<String, String>();
+
+        assertTrue(uriTemplate.match("/1%202/%203", values));
+        assertFalse(uriTemplate.match("/1 2/%203", values));
+    }
+    
     @Test
     public void testBasicCustomExpression4() throws Exception {
         URITemplate uriTemplate = new URITemplate("/books/{bookId:...\\.}");
@@ -559,9 +659,10 @@ public class URITemplateTest extends Assert {
         assertFalse(tok.hasNext());
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test
     public void testUnclosedVariable() {
-        new URITemplate("/foo/{var/bar");
+        URITemplate ut = new URITemplate("/foo/{var/bar");
+        assertEquals("/foo/{var/bar", ut.getValue());
     }
 
     @Test
