@@ -37,7 +37,6 @@ import javax.ws.rs.core.Response;
 import javax.xml.bind.annotation.XmlTransient;
 
 import org.apache.cxf.aegis.type.java5.IgnoreProperty;
-import org.apache.cxf.jaxrs.ext.multipart.MultipartBody;
 import org.apache.cxf.jaxrs.fortest.jaxb.packageinfo.Book2;
 import org.apache.cxf.jaxrs.model.wadl.jaxb.Book;
 import org.apache.cxf.jaxrs.model.wadl.jaxb.Chapter;
@@ -48,15 +47,6 @@ import org.apache.cxf.jaxrs.model.wadl.jaxb.Chapter;
 @Description(lang = "en-us", title = "book store resource", value = "super resource")
 public class BookStore {
 
-    @Descriptions({ 
-        @Description(value = "Attachments", target = DocTarget.PARAM)
-    })
-    @POST 
-    @Consumes("multipart/form-data")
-    public void formdata(MultipartBody body) {
-        
-    }
-    
     @GET 
     @Produces("text/plain")
     public String getName(@PathParam("id") Long id, @QueryParam("") QueryBean query) {
@@ -191,9 +181,6 @@ public class BookStore {
             return bean;
         }
         
-        public QueryBean2 getIt() {
-            return this;
-        }
     }
     
     public static class QueryBean3 {
