@@ -45,8 +45,8 @@ import org.apache.cxf.message.MessageImpl;
 import org.apache.cxf.service.Service;
 import org.apache.cxf.service.model.EndpointInfo;
 import org.apache.cxf.transport.servlet.ServletDestination;
-import org.easymock.EasyMock;
-import org.easymock.IMocksControl;
+import org.easymock.classextension.EasyMock;
+import org.easymock.classextension.IMocksControl;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
@@ -359,8 +359,8 @@ public class WadlGeneratorTest extends Assert {
         // must have a single template parameter
         verifyParameters(resource, 1, new Param("id", "template", "xs:long"));
         
-        // must have 3 methods, GET, POST and PUT
-        List<Element> methodEls = getElements(resource, "method", 3);
+        // must have 2 methods, GET and PUT
+        List<Element> methodEls = getElements(resource, "method", 2);
         
         // verify GET
         assertEquals("GET", methodEls.get(0).getAttribute("name"));
@@ -382,16 +382,11 @@ public class WadlGeneratorTest extends Assert {
         //check response
         verifyRepresentation(methodEls.get(0), "response", "text/plain", "");
         
-        // verify POST
-        assertEquals("POST", methodEls.get(1).getAttribute("name"));
-        Element formRep = verifyRepresentation(methodEls.get(1), "request", "multipart/form-data", "");
-        checkDocs(formRep, "", "Attachments", "");
-        
         // verify PUT
-        assertEquals("PUT", methodEls.get(2).getAttribute("name"));
-        verifyRepresentation(methodEls.get(2), "request", "text/plain", "");
+        assertEquals("PUT", methodEls.get(1).getAttribute("name"));
+        verifyRepresentation(methodEls.get(1), "request", "text/plain", "");
         
-        verifyResponseWithStatus(methodEls.get(2), "204");
+        verifyResponseWithStatus(methodEls.get(1), "204");
         
         // verify resource starting with /book2
         verifyGetResourceMethod(resourceEls.get(0), book2El, null);
@@ -538,7 +533,7 @@ public class WadlGeneratorTest extends Assert {
             WadlGenerator.WADL_NS, "representation").size());
     }
     
-    private Element verifyRepresentation(Element element, 
+    private void verifyRepresentation(Element element, 
                                       String name, 
                                       String mediaType,
                                       String elementValue) {
@@ -553,7 +548,6 @@ public class WadlGeneratorTest extends Assert {
             String pName = "request".equals(name) ? "request" : "result";
             verifyParameters(representationEls.get(0), 1, new Param(pName, "plain", "xs:string"));
         }
-        return representationEls.get(0);
     }
     
     private void verifyXmlJsonRepresentations(Element element, String type, String docs) {
