@@ -30,13 +30,20 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.ArrayBlockingQueue;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
 
+import javax.activation.DataHandler;
+import javax.activation.DataSource;
 import javax.ws.rs.Consumes;
 import javax.ws.rs.Produces;
 import javax.ws.rs.WebApplicationException;
 import javax.ws.rs.core.MediaType;
 import javax.ws.rs.core.MultivaluedMap;
 import javax.ws.rs.core.Response;
+import javax.ws.rs.core.UriInfo;
 import javax.ws.rs.ext.ContextResolver;
 import javax.ws.rs.ext.ExceptionMapper;
 import javax.ws.rs.ext.MessageBodyReader;
@@ -53,6 +60,7 @@ import org.apache.cxf.jaxrs.Customer;
 import org.apache.cxf.jaxrs.CustomerParameterHandler;
 import org.apache.cxf.jaxrs.JAXBContextProvider;
 import org.apache.cxf.jaxrs.JAXBContextProvider2;
+import org.apache.cxf.jaxrs.ext.MessageContext;
 import org.apache.cxf.jaxrs.ext.ParameterHandler;
 import org.apache.cxf.jaxrs.ext.RequestHandler;
 import org.apache.cxf.jaxrs.impl.MetadataMap;
@@ -66,10 +74,11 @@ import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.ExchangeImpl;
 import org.apache.cxf.message.Message;
 import org.apache.cxf.message.MessageImpl;
-import org.easymock.classextension.EasyMock;
+import org.easymock.EasyMock;
 
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.Ignore;
 import org.junit.Test;
 
 public class ProviderFactoryTest extends Assert {
@@ -130,6 +139,175 @@ public class ProviderFactoryTest extends Assert {
         assertSame(th, pf.getRequestHandlers().get(1).getProvider());
     }
     
+    @Test
+    public void testDefaultJaxbProvider() throws Exception {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        doTestDefaultJaxbProviderCloned(pf, "http://localhost:8080/base/");
+        checkJaxbProvider(pf);
+    }
+    
+    @Test
+    public void testDefaultJaxbProviderMultipleThreads() throws Exception {
+        for (int i = 0; i < 100; i++) {
+            doTestDefaultJaxbProviderClonedMultipleThreads();
+        }
+    }
+    
+    
+    public void doTestDefaultJaxbProviderClonedMultipleThreads() throws Exception {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        ThreadPoolExecutor executor = new ThreadPoolExecutor(50, 50, 0, TimeUnit.SECONDS,
+                                                             new ArrayBlockingQueue<Runnable>(10));
+        CountDownLatch startSignal = new CountDownLatch(1);
+        CountDownLatch doneSignal = new CountDownLatch(50);
+        
+        addThreads(executor, pf, startSignal, doneSignal, 50);
+        
+        startSignal.countDown();
+        doneSignal.await(60, TimeUnit.SECONDS);
+        executor.shutdownNow();
+        assertEquals("Not all invocations have completed", 0, doneSignal.getCount());
+        checkJaxbProvider(pf);
+    }
+    
+    private void addThreads(ThreadPoolExecutor executor, ProviderFactory pf,
+                            CountDownLatch startSignal, CountDownLatch doneSignal, int count) {
+        
+        for (int i = 1; i <= count; i++) {
+            executor.execute(new TestRunnable(pf, startSignal, doneSignal, 
+                                              "http://localhost:8080/base/" + i));
+        }
+    }
+    
+    private void doTestDefaultJaxbProviderCloned(ProviderFactory pf, String property) {
+        Message message = new MessageImpl();
+        message.put(Message.QUERY_STRING, "uri=" + property);
+        MessageBodyReader customJaxbReader = pf.createMessageBodyReader((Class<?>)Book.class, null, null, 
+                                                              MediaType.TEXT_XML_TYPE, message);
+        assertTrue(customJaxbReader instanceof JAXBElementProvider);
+        
+        JAXBElementProvider provider = (JAXBElementProvider)customJaxbReader;
+        MessageContext mc = provider.getContext();
+        assertNotNull(mc);
+        UriInfo ui = mc.getUriInfo();
+        MultivaluedMap<String, String> queries = ui.getQueryParameters();
+        assertEquals(1, queries.size());
+        List<String> uriQuery = queries.get("uri");
+        assertEquals(1, uriQuery.size());
+        assertEquals(property, uriQuery.get(0));
+        
+        MessageBodyReader customJaxbReader2 = pf.createMessageBodyReader((Class<?>)Book.class, null, null, 
+                                                              MediaType.TEXT_XML_TYPE, message);
+        assertSame(customJaxbReader, customJaxbReader2);
+         
+        MessageBodyWriter customJaxbWriter = pf.createMessageBodyWriter((Class<?>)Book.class, null, null, 
+                                                              MediaType.TEXT_XML_TYPE, message);
+        assertSame(customJaxbReader, customJaxbWriter);
+        
+        MessageBodyReader jaxbReader = ProviderFactory.getSharedInstance().createMessageBodyReader(
+            (Class<?>)Book.class, null, null, MediaType.TEXT_XML_TYPE, message);
+        assertTrue(jaxbReader instanceof JAXBElementProvider);
+        assertNotSame(jaxbReader, customJaxbReader);
+    }
+    
+    private void checkJaxbProvider(ProviderFactory pf) {
+        int count = 0;
+        for (Object provider : pf.getReadersWriters()) {
+            if (((ProviderInfo)provider).getProvider() instanceof JAXBElementProvider) {
+                count++;
+            }
+        }
+        assertEquals(1, count);
+    }
+    
+    @Test
+    public void testCustomJaxbProvider() {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        JAXBElementProvider provider = new JAXBElementProvider();
+        pf.registerUserProvider(provider);
+        MessageBodyReader customJaxbReader = pf.createMessageBodyReader((Class<?>)Book.class, null, null, 
+                                                              MediaType.TEXT_XML_TYPE, new MessageImpl());
+        assertSame(customJaxbReader, provider);
+        
+        MessageBodyWriter customJaxbWriter = pf.createMessageBodyWriter((Class<?>)Book.class, null, null, 
+                                                              MediaType.TEXT_XML_TYPE, new MessageImpl());
+        assertSame(customJaxbWriter, provider);
+    }
+    
+    @Test
+    public void testCustomJsonProvider() {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        JSONProvider provider = new JSONProvider();
+        pf.registerUserProvider(provider);
+        MessageBodyReader customJsonReader = pf.createMessageBodyReader((Class<?>)Book.class, null, null, 
+                                               MediaType.APPLICATION_JSON_TYPE, new MessageImpl());
+        assertSame(customJsonReader, provider);
+        
+        MessageBodyWriter customJsonWriter = pf.createMessageBodyWriter((Class<?>)Book.class, null, null, 
+                                               MediaType.APPLICATION_JSON_TYPE, new MessageImpl());
+        assertSame(customJsonWriter, provider);
+    }
+    
+    @Test
+    public void testDefaultJsonProviderCloned() {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        MessageBodyReader customJsonReader = pf.createMessageBodyReader((Class<?>)Book.class, null, null, 
+                                                MediaType.APPLICATION_JSON_TYPE, new MessageImpl());
+        assertTrue(customJsonReader instanceof JSONProvider);
+        
+        MessageBodyReader customJsonReader2 = pf.createMessageBodyReader((Class<?>)Book.class, null, null, 
+                                                MediaType.APPLICATION_JSON_TYPE, new MessageImpl());
+        assertSame(customJsonReader, customJsonReader2);
+        
+        MessageBodyWriter customJsonWriter = pf.createMessageBodyWriter((Class<?>)Book.class, null, null, 
+                                                MediaType.APPLICATION_JSON_TYPE, new MessageImpl());
+        assertSame(customJsonReader, customJsonWriter);
+        
+        MessageBodyReader jsonReader = ProviderFactory.getSharedInstance().createMessageBodyReader(
+            (Class<?>)Book.class, null, null, MediaType.APPLICATION_JSON_TYPE, new MessageImpl());
+        assertTrue(jsonReader instanceof JSONProvider);
+        assertNotSame(jsonReader, customJsonReader);
+    }
+    
+    @Test
+    public void testDataSourceReader() {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        pf.registerUserProvider(new DataSourceProvider());
+        MessageBodyReader reader = pf.createMessageBodyReader(
+              (Class<?>)DataSource.class, null, null, 
+              MediaType.valueOf("image/png"), new MessageImpl());
+        assertTrue(reader instanceof DataSourceProvider);
+        MessageBodyReader reader2 = pf.createMessageBodyReader(
+                          (Class<?>)DataHandler.class, null, null, 
+                          MediaType.valueOf("image/png"), new MessageImpl());
+        assertSame(reader, reader2);
+    }
+    
+    @Test
+    public void testDataSourceWriter() {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        pf.registerUserProvider(new DataSourceProvider());
+        MessageBodyWriter writer = pf.createMessageBodyWriter(
+              (Class<?>)DataSource.class, null, null, 
+              MediaType.valueOf("image/png"), new MessageImpl());
+        assertTrue(writer instanceof DataSourceProvider);
+        MessageBodyWriter writer2 = pf.createMessageBodyWriter(
+                          (Class<?>)DataHandler.class, null, null, 
+                          MediaType.valueOf("image/png"), new MessageImpl());
+        assertSame(writer, writer2);
+    }
+    
+    @Test
+    public void testNoDataSourceWriter() {
+        ProviderFactory pf = ProviderFactory.getInstance();
+        pf.registerUserProvider(new DataSourceProvider());
+        MessageBodyWriter writer = pf.createMessageBodyWriter(
+              (Class<?>)DataSource.class, null, null, 
+              MediaType.valueOf("multipart/form-data"), new MessageImpl());
+        assertFalse(writer instanceof DataSourceProvider);
+    }
+    
+    
     @Test
     public void testSchemaLocations() {
         ProviderFactory pf = ProviderFactory.getInstance();
@@ -223,6 +401,7 @@ public class ProviderFactoryTest extends Assert {
         assertSame(exMapper2, pf.createExceptionMapper(WebApplicationException.class, new MessageImpl()));
     }
     
+    @Test
     public void testMessageBodyHandlerHierarchy() throws Exception {
         ProviderFactory pf = ProviderFactory.getInstance();
         List<Object> providers = new ArrayList<Object>();
@@ -741,7 +920,39 @@ public class ProviderFactoryTest extends Assert {
         }
         
     }
+    
+    @Ignore
+    private class TestRunnable implements Runnable {
 
+        private CountDownLatch startSignal;
+        private CountDownLatch doneSignal;
+        private ProviderFactory pf;
+        private String property; 
+        public TestRunnable(ProviderFactory pf,
+                            CountDownLatch startSignal,
+                            CountDownLatch doneSignal,
+                            String property) {
+            this.startSignal = startSignal;
+            this.doneSignal = doneSignal;
+            this.pf = pf;
+            this.property = property;
+        }
+        
+        public void run() {
+            
+            try {
+                startSignal.await();
+                ProviderFactoryTest.this.doTestDefaultJaxbProviderCloned(pf, property);
+                doneSignal.countDown();
+            } catch (Exception ex) {
+                ex.printStackTrace();
+                Assert.fail(ex.getMessage());
+            } 
+            
+        }
+        
+    }
+    
     private static class RuntimeExceptionMapper1 
         extends AbstractTestExceptionMapper<RuntimeException> {
         
