@@ -71,7 +71,7 @@ import org.apache.cxf.ws.addressing.EndpointReferenceType;
 import org.apache.cxf.ws.addressing.JAXWSAConstants;
 import org.apache.cxf.ws.policy.PolicyEngine;
 import org.apache.cxf.wsdl.EndpointReferenceUtils;
-import org.easymock.EasyMock;
+import org.easymock.classextension.EasyMock;
 import org.eclipse.jetty.http.HttpFields;
 import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Response;
@@ -674,8 +674,6 @@ public class JettyHTTPDestinationTest extends Assert {
         EasyMock.expectLastCall().andReturn(method).atLeastOnce();
         request.getConnection();
         EasyMock.expectLastCall().andReturn(null).anyTimes();
-        request.getUserPrincipal();
-        EasyMock.expectLastCall().andReturn(null).anyTimes();
         
         if (setRedirectURL) {
             policy.setRedirectURL(NOWHERE + "foo/bar");
@@ -753,20 +751,16 @@ public class JettyHTTPDestinationTest extends Assert {
         }
         
         if (decoupled) {
-            setupDecoupledBackChannel();
+            decoupledBackChannel = EasyMock.createMock(Conduit.class);
+            decoupledBackChannel.setMessageObserver(EasyMock.isA(MessageObserver.class));           
+            decoupledBackChannel.prepare(EasyMock.isA(Message.class));
+            EasyMock.expectLastCall();
+            EasyMock.replay(decoupledBackChannel);
         }
         EasyMock.replay(response);
         EasyMock.replay(request);
     }
     
-    private void setupDecoupledBackChannel() throws IOException {
-        decoupledBackChannel = EasyMock.createMock(Conduit.class);
-        decoupledBackChannel.setMessageObserver(EasyMock.isA(MessageObserver.class));           
-        decoupledBackChannel.prepare(EasyMock.isA(Message.class));
-        EasyMock.expectLastCall();
-        EasyMock.replay(decoupledBackChannel);
-    }
-    
     private void setUpInMessage() {
         inMessage.setExchange(new ExchangeImpl());
     }
