@@ -26,9 +26,9 @@ import java.security.Principal;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Enumeration;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.TreeMap;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -158,7 +158,7 @@ public final class JMSUtils {
         Map<String, List<String>> headers = CastUtils.cast((Map)inMessage
             .get(org.apache.cxf.message.Message.PROTOCOL_HEADERS));
         if (headers == null) {
-            headers = new HashMap<String, List<String>>();
+            headers = new TreeMap<String, List<String>>();
             inMessage.put(org.apache.cxf.message.Message.PROTOCOL_HEADERS, headers);
         }
         headers.put(JMSSpecConstants.JMS_MESSAGE_TYPE, Collections.singletonList(messageType));
@@ -193,7 +193,8 @@ public final class JMSUtils {
                 }
             }
 
-            Map<String, List<String>> protHeaders = new HashMap<String, List<String>>();
+            Map<String, List<String>> protHeaders
+                = new TreeMap<String, List<String>>();
             List<JMSPropertyType> props = messageProperties.getProperty();
             Enumeration enm = message.getPropertyNames();
             while (enm.hasMoreElements()) {
@@ -265,7 +266,7 @@ public final class JMSUtils {
                 Map<String, List<String>> headers = CastUtils.cast((Map)inMessage
                     .get(org.apache.cxf.message.Message.PROTOCOL_HEADERS));
                 if (headers == null) {
-                    headers = new HashMap<String, List<String>>();
+                    headers = new TreeMap<String, List<String>>();
                     inMessage.put(org.apache.cxf.message.Message.PROTOCOL_HEADERS, headers);
                 }
                 try {
@@ -360,6 +361,7 @@ public final class JMSUtils {
         return normalizedEncoding;
     }
 
+    /*
     protected static void addProtocolHeaders(Message message, Map<String, List<String>> headers)
         throws JMSException {
         if (headers == null) {
@@ -385,13 +387,14 @@ public final class JMSUtils {
 
         }
     }
-
+*/
     public static void addContentTypeToProtocolHeader(org.apache.cxf.message.Message message) {
         String contentType = (String)message.get(org.apache.cxf.message.Message.CONTENT_TYPE);
         String enc = (String)message.get(org.apache.cxf.message.Message.ENCODING);
         // add the encoding information
         if (null != contentType) {
-            if (enc != null && contentType.indexOf("charset=") == -1) {
+            if (enc != null && contentType.indexOf("charset=") == -1
+                && !contentType.toLowerCase().contains("multipart/related")) {
                 contentType = contentType + "; charset=" + enc;
             }
         } else if (enc != null) {
@@ -404,7 +407,7 @@ public final class JMSUtils {
         Map<String, List<String>> headers = CastUtils.cast((Map<?, ?>)message
             .get(org.apache.cxf.message.Message.PROTOCOL_HEADERS));
         if (null == headers) {
-            headers = new HashMap<String, List<String>>();
+            headers = new TreeMap<String, List<String>>();
             message.put(org.apache.cxf.message.Message.PROTOCOL_HEADERS, headers);
         }
 
@@ -426,7 +429,8 @@ public final class JMSUtils {
         String enc = (String)message.get(org.apache.cxf.message.Message.ENCODING);
         // add the encoding information
         if (null != contentType) {
-            if (enc != null && contentType.indexOf("charset=") == -1) {
+            if (enc != null && contentType.indexOf("charset=") == -1
+                && !contentType.toLowerCase().contains("multipart/related")) {
                 contentType = contentType + "; charset=" + enc;
             }
         } else if (enc != null) {
@@ -439,7 +443,7 @@ public final class JMSUtils {
         Map<String, List<String>> headers = CastUtils.cast((Map<?, ?>)message
             .get(org.apache.cxf.message.Message.PROTOCOL_HEADERS));
         if (null == headers) {
-            headers = new HashMap<String, List<String>>();
+            headers = new TreeMap<String, List<String>>(String.CASE_INSENSITIVE_ORDER);
             message.put(org.apache.cxf.message.Message.PROTOCOL_HEADERS, headers);
         }
         return contentType;
@@ -607,11 +611,20 @@ public final class JMSUtils {
         Map<String, List<String>> headers = CastUtils.cast((Map<?, ?>)outMessage
             .get(org.apache.cxf.message.Message.PROTOCOL_HEADERS));
         if (headers != null) {
-            List<String> action = headers.get(SOAPConstants.SOAP_ACTION);
+            List<String> action = headers.remove(SOAPConstants.SOAP_ACTION);
             if (action != null && action.size() > 0) {
                 soapAction = action.get(0);
             }
         }
+        
+        if (soapAction == null) {
+            soapAction = messageProperties.getSOAPJMSSOAPAction();
+        }
+        
+        if (soapAction == null) {
+            soapAction = extractActionFromSoap12(outMessage);
+        }
+        
         if (soapAction != null) {
             messageProperties.setSOAPJMSSOAPAction(soapAction);
         }
@@ -625,6 +638,23 @@ public final class JMSUtils {
         if (!messageProperties.isSetSOAPJMSRequestURI()) {
             messageProperties.setSOAPJMSRequestURI(jmsConfig.getRequestURI());
         }
+        for (Map.Entry<String, List<String>> ent : headers.entrySet()) {
+            JMSPropertyType prop = new JMSPropertyType();
+            prop.setName(ent.getKey());
+            if (ent.getValue().size() > 1) {
+                StringBuilder b = new StringBuilder();
+                for (String s : ent.getValue()) {
+                    if (b.length() > 0) {
+                        b.append(',');
+                    }
+                    b.append(s);
+                }
+                prop.setValue(b.toString());
+            } else {
+                prop.setValue(ent.getValue().get(0));
+            }
+            messageProperties.getProperty().add(prop);
+        }
     }
 
     /**
@@ -651,4 +681,29 @@ public final class JMSUtils {
         id.append(index);
         return id.toString();
     }
+    
+    private static String extractActionFromSoap12(org.apache.cxf.message.Message message) {
+        String ct = (String) message.get(org.apache.cxf.message.Message.CONTENT_TYPE);
+        
+        if (ct == null) {
+            return null;
+        }
+        
+        int start = ct.indexOf("action=");
+        if (start != -1) {
+            int end;
+            if (ct.charAt(start + 7) == '\"') {
+                start += 8;
+                end = ct.indexOf('\"', start);
+            } else {
+                start += 7;
+                end = ct.indexOf(';', start);
+                if (end == -1) {
+                    end = ct.length();
+                }
+            }
+            return ct.substring(start, end);
+        }
+        return null;
+    }
 }
