@@ -463,10 +463,12 @@ public class MAPAggregator extends AbstractPhaseInterceptor<Message> {
                         || (aicNonAnon2 != null && !aicNonAnon2.isEmpty());
                 
             if (hasAnonymous && hasNonAnon && !hasAnon) {
+                message.put(FaultMode.class, FaultMode.UNCHECKED_APPLICATION_FAULT);
                 throw new SoapFault("Found anonymous address but non-anonymous required",
                                     new QName(Names.WSA_NAMESPACE_NAME,
                                               "OnlyNonAnonymousAddressSupported"));
             } else if (!onlyAnonymous && !hasNonAnon && hasAnon) {
+                message.put(FaultMode.class, FaultMode.UNCHECKED_APPLICATION_FAULT);
                 throw new SoapFault("Found non-anonymous address but only anonymous supported",
                                     new QName(Names.WSA_NAMESPACE_NAME,
                                               "OnlyAnonymousAddressSupported"));
@@ -615,9 +617,22 @@ public class MAPAggregator extends AbstractPhaseInterceptor<Message> {
                     }
                 }
                 if (missingWsaHeader) {
-                    String reason = BUNDLE.getString("MISSING_ACTION_MESSAGE");
-                    throw new SoapFault(reason, new QName(Names.WSA_NAMESPACE_NAME,
-                                                          Names.HEADER_REQUIRED_NAME));
+                    throw new SoapFault("MISSING_ACTION_MESSAGE", BUNDLE,
+                                        new QName(Names.WSA_NAMESPACE_NAME,
+                                                  Names.HEADER_REQUIRED_NAME));
+                }
+            }
+            if (MessageUtils.isPartialResponse(message) 
+                && message.getExchange().getOutMessage() != null) {
+                // marked as a partial response, let's see if it really is
+                MessageInfo min = message.get(MessageInfo.class);
+                MessageInfo mout = message.getExchange().getOutMessage().get(MessageInfo.class);
+                if (min != null && mout != null 
+                    && min.getOperation() == mout.getOperation()
+                    && message.getContent(List.class) != null) {
+                    // the in and out messages are on the same operation 
+                    // and we were able to get a response for it.
+                    message.remove(Message.PARTIAL_RESPONSE_MESSAGE);
                 }
             }
         }
@@ -777,21 +792,12 @@ public class MAPAggregator extends AbstractPhaseInterceptor<Message> {
             op = ((UnwrappedOperationInfo)op).getWrappedOperation();
         }
         //CXF-2836:To correct the wsa:action header value for dispatch client
-        if (bop.getProperty("dispatchToOperation") != null) {
+        BindingOperationInfo dbop = (BindingOperationInfo)bop.getProperty("dispatchToOperation");
+        if (null != dbop) {
             //modifies the bop and bp to the value of dispatch client really invokes, 
             //This helps corrct the wsa:action header value
-            QName opName = (QName)bop.getProperty("dispatchToOperation");
-            OperationInfo dispatchOP = bop.getBinding().getService().getInterface().getOperation(opName);
-            BindingOperationInfo dispachBop = null;
-            for (BindingOperationInfo binfo : bop.getBinding().getOperations()) {
-                if (binfo.getOperationInfo().getName().toString().equals(opName.toString())) {
-                    dispachBop = binfo;
-                }
-            }
-            if (dispachBop != null && dispatchOP != null) {
-                bop = dispachBop;
-                op = dispatchOP;
-            }
+            bop = dbop;
+            op = dbop.getOperationInfo();
         }
         
         String actionUri = null;
