@@ -107,12 +107,6 @@ public class PolicyAnnotationTest extends Assert {
             check(xpu, wsdl, "/wsdl:definitions/wsdl:binding/wsdl:operation/wsdl:output",
                   "echoIntBindingOpOutputPolicy");
             check(xpu, wsdl, "/wsdl:definitions/wsdl:service/", "TestImplServiceServicePolicy");
-            
-            
-            EndpointPolicy policy = bus.getExtension(PolicyEngine.class)
-                .getServerEndpointPolicy(s.getEndpoint().getEndpointInfo(), null);
-            assertNotNull(policy);
-            assertEquals(1, policy.getChosenAlternative().size());
         } finally {
             bus.shutdown(true);
         }
@@ -174,8 +168,6 @@ public class PolicyAnnotationTest extends Assert {
             check(xpu, wsdl, "/wsdl:definitions/wsdl:binding/wsdl:operation/wsdl:output",
                   "echoIntBindingOpOutputPolicy");
             check(xpu, wsdl, "/wsdl:definitions/wsdl:service/", "TestInterfaceServiceServicePolicy");
-            
-            
         } finally {
             bus.shutdown(true);
         }
