@@ -20,12 +20,9 @@
 package org.apache.cxf.ws.rm.persistence.jdbc;
 
 
-import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.math.BigDecimal;
-import java.math.BigInteger;
 import java.sql.Blob;
 import java.sql.Connection;
 import java.sql.DriverManager;
@@ -46,7 +43,6 @@ import javax.annotation.PostConstruct;
 
 import org.apache.cxf.common.i18n.Message;
 import org.apache.cxf.common.logging.LogUtils;
-import org.apache.cxf.helpers.IOUtils;
 import org.apache.cxf.ws.addressing.v200408.EndpointReferenceType;
 import org.apache.cxf.ws.rm.DestinationSequence;
 import org.apache.cxf.ws.rm.Identifier;
@@ -67,23 +63,23 @@ public class RMTxStore implements RMStore {
         "CREATE TABLE CXF_RM_DEST_SEQUENCES " 
         + "(SEQ_ID VARCHAR(256) NOT NULL, "
         + "ACKS_TO VARCHAR(1024) NOT NULL, "
-        + "LAST_MSG_NO DECIMAL(31, 0), "
+        + "LAST_MSG_NO DECIMAL(19, 0), "
         + "ENDPOINT_ID VARCHAR(1024), "
         + "ACKNOWLEDGED BLOB, "
         + "PRIMARY KEY (SEQ_ID))";
     private static final String CREATE_SRC_SEQUENCES_TABLE_STMT =
         "CREATE TABLE CXF_RM_SRC_SEQUENCES " 
         + "(SEQ_ID VARCHAR(256) NOT NULL, "
-        + "CUR_MSG_NO DECIMAL(31, 0) DEFAULT 1 NOT NULL, "
+        + "CUR_MSG_NO DECIMAL(19, 0) DEFAULT 1 NOT NULL, "
         + "LAST_MSG CHAR(1), "
-        + "EXPIRY DECIMAL(31, 0), "
+        + "EXPIRY DECIMAL(19, 0), "
         + "OFFERING_SEQ_ID VARCHAR(256), "
         + "ENDPOINT_ID VARCHAR(1024), "            
         + "PRIMARY KEY (SEQ_ID))";
     private static final String CREATE_MESSAGES_TABLE_STMT =
         "CREATE TABLE {0} " 
         + "(SEQ_ID VARCHAR(256) NOT NULL, "
-        + "MSG_NO DECIMAL(31, 0) NOT NULL, "
+        + "MSG_NO DECIMAL(19, 0) NOT NULL, "
         + "SEND_TO VARCHAR(256), "
         + "CONTENT BLOB, "
         + "PRIMARY KEY (SEQ_ID, MSG_NO))";
@@ -107,6 +103,12 @@ public class RMTxStore implements RMStore {
         = "INSERT INTO {0} VALUES(?, ?, ?, ?)";
     private static final String DELETE_MESSAGE_STMT_STR =
         "DELETE FROM {0} WHERE SEQ_ID = ? AND MSG_NO = ?";
+    private static final String SELECT_DEST_SEQUENCE_STMT_STR =
+        "SELECT ACKS_TO, LAST_MSG_NO, ACKNOWLEDGED FROM CXF_RM_DEST_SEQUENCES "
+        + "WHERE SEQ_ID = ?";
+    private static final String SELECT_SRC_SEQUENCE_STMT_STR =
+        "SELECT CUR_MSG_NO, LAST_MSG, EXPIRY, OFFERING_SEQ_ID FROM CXF_RM_SRC_SEQUENCES "
+        + "WHERE SEQ_ID = ?";
     private static final String SELECT_DEST_SEQUENCES_STMT_STR =
         "SELECT SEQ_ID, ACKS_TO, LAST_MSG_NO, ACKNOWLEDGED FROM CXF_RM_DEST_SEQUENCES "
         + "WHERE ENDPOINT_ID = ?";
@@ -132,6 +134,8 @@ public class RMTxStore implements RMStore {
     private PreparedStatement updateSrcSequenceStmt;
     private PreparedStatement selectDestSequencesStmt;
     private PreparedStatement selectSrcSequencesStmt;
+    private PreparedStatement selectDestSequenceStmt;
+    private PreparedStatement selectSrcSequenceStmt;
     private PreparedStatement createInboundMessageStmt;
     private PreparedStatement createOutboundMessageStmt;
     private PreparedStatement deleteInboundMessageStmt;
@@ -144,6 +148,9 @@ public class RMTxStore implements RMStore {
     private String userName;
     private String password;
     
+    private String tableExistsState = DERBY_TABLE_EXISTS_STATE;
+    private int tableExistsCode = ORACLE_TABLE_EXISTS_CODE;
+    
     // configuration
     
     public void setDriverClassName(String dcn) {
@@ -176,8 +183,24 @@ public class RMTxStore implements RMStore {
     
     public String getUserName() {
         return userName;
-    }    
+    }
    
+    public String getTableExistsState() {
+        return tableExistsState;
+    }
+
+    public void setTableExistsState(String tableExistsState) {
+        this.tableExistsState = tableExistsState;
+    }
+
+    public int getTableExistsCode() {
+        return tableExistsCode;
+    }
+
+    public void setTableExistsCode(int tableExistsCode) {
+        this.tableExistsCode = tableExistsCode;
+    }
+
     public void setConnection(Connection c) {
         connection = c;
     }
@@ -243,6 +266,68 @@ public class RMTxStore implements RMStore {
         }
     }
     
+    public DestinationSequence getDestinationSequence(Identifier sid) {
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.info("Getting destination sequence for id: " + sid);
+        }
+        try {
+            if (null == selectDestSequenceStmt) {
+                selectDestSequenceStmt = 
+                    connection.prepareStatement(SELECT_DEST_SEQUENCE_STMT_STR);               
+            }
+            selectDestSequenceStmt.setString(1, sid.getValue());
+            
+            ResultSet res = selectDestSequenceStmt.executeQuery(); 
+            if (res.next()) {
+                EndpointReferenceType acksTo = RMUtils.createReference2004(res.getString(1));  
+                long lm = res.getLong(2);
+                InputStream is = res.getBinaryStream(3); 
+                SequenceAcknowledgement ack = null;
+                if (null != is) {
+                    ack = PersistenceUtils.getInstance()
+                        .deserialiseAcknowledgment(is); 
+                }
+                return new DestinationSequence(sid, acksTo, lm, ack);
+            }
+        } catch (SQLException ex) {
+            LOG.log(Level.WARNING, new Message("SELECT_DEST_SEQ_FAILED_MSG", LOG).toString(), ex);
+        }
+        return null;
+    }
+    
+    public SourceSequence getSourceSequence(Identifier sid) {
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.info("Getting source sequences for id: " + sid);
+        }
+        try {
+            if (null == selectSrcSequenceStmt) {
+                selectSrcSequenceStmt = 
+                    connection.prepareStatement(SELECT_SRC_SEQUENCE_STMT_STR);     
+            }
+            selectSrcSequenceStmt.setString(1, sid.getValue());
+            ResultSet res = selectSrcSequenceStmt.executeQuery();
+            
+            if (res.next()) {
+                long cmn = res.getLong(1);
+                boolean lm = res.getBoolean(2);
+                long lval = res.getLong(3);
+                Date expiry = 0 == lval ? null : new Date(lval);
+                String oidValue = res.getString(4);
+                Identifier oi = null;
+                if (null != oidValue) {
+                    oi = RMUtils.getWSRMFactory().createIdentifier();
+                    oi.setValue(oidValue);
+                }                            
+                return new SourceSequence(sid, expiry, oi, cmn, lm);
+                          
+            }
+        } catch (SQLException ex) {
+            // ignore
+            LOG.log(Level.WARNING, new Message("SELECT_SRC_SEQ_FAILED_MSG", LOG).toString(), ex);
+        }
+        return null;
+    }
+
     public void removeDestinationSequence(Identifier sid) {
         try {
             beginTransaction();
@@ -297,15 +382,14 @@ public class RMTxStore implements RMStore {
                 Identifier sid = RMUtils.getWSRMFactory().createIdentifier();                
                 sid.setValue(res.getString(1));
                 EndpointReferenceType acksTo = RMUtils.createReference2004(res.getString(2));  
-                BigDecimal lm = res.getBigDecimal(3);
+                long lm = res.getLong(3);
                 InputStream is = res.getBinaryStream(4); 
                 SequenceAcknowledgement ack = null;
                 if (null != is) {
                     ack = PersistenceUtils.getInstance()
                         .deserialiseAcknowledgment(is); 
                 }
-                DestinationSequence seq = new DestinationSequence(sid, acksTo, 
-                                                                  lm == null ? null : lm.toBigInteger(), ack);
+                DestinationSequence seq = new DestinationSequence(sid, acksTo, lm, ack);
                 seqs.add(seq);                                                 
             }
         } catch (SQLException ex) {
@@ -330,7 +414,7 @@ public class RMTxStore implements RMStore {
             while (res.next()) {
                 Identifier sid = RMUtils.getWSRMFactory().createIdentifier();
                 sid.setValue(res.getString(1));
-                BigInteger cmn = res.getBigDecimal(2).toBigInteger();
+                long cmn = res.getLong(2);
                 boolean lm = res.getBoolean(3);
                 long lval = res.getLong(4);
                 Date expiry = 0 == lval ? null : new Date(lval);
@@ -366,20 +450,19 @@ public class RMTxStore implements RMStore {
             stmt.setString(1, sid.getValue());
             ResultSet res = stmt.executeQuery();
             while (res.next()) {
-                BigInteger mn = res.getBigDecimal(1).toBigInteger();
+                long mn = res.getLong(1);
                 String to = res.getString(2);
                 Blob blob = res.getBlob(3);
-                byte[] bytes = blob.getBytes(1, (int)blob.length());     
                 RMMessage msg = new RMMessage();
                 msg.setMessageNumber(mn);
                 msg.setTo(to);
-                msg.setContent(bytes);
+                msg.setContent(blob.getBinaryStream());
                 msgs.add(msg);                
             }            
-        } catch (SQLException ex) {
+        } catch (Exception ex) {
             LOG.log(Level.WARNING, new Message(outbound ? "SELECT_OUTBOUND_MSGS_FAILED_MSG"
                 : "SELECT_INBOUND_MSGS_FAILED_MSG", LOG).toString(), ex);
-        }        
+        }
         return msgs;
     }
 
@@ -420,7 +503,7 @@ public class RMTxStore implements RMStore {
         }        
     }
 
-    public void removeMessages(Identifier sid, Collection<BigInteger> messageNrs, boolean outbound) {
+    public void removeMessages(Identifier sid, Collection<Long> messageNrs, boolean outbound) {
         try {
             beginTransaction();
             PreparedStatement stmt = outbound ? deleteOutboundMessageStmt : deleteInboundMessageStmt;
@@ -436,8 +519,8 @@ public class RMTxStore implements RMStore {
 
             stmt.setString(1, sid.getValue());
                         
-            for (BigInteger messageNr : messageNrs) {
-                stmt.setBigDecimal(2, new BigDecimal(messageNr));
+            for (Long messageNr : messageNrs) {
+                stmt.setLong(2, messageNr);
                 stmt.execute();
             }
             
@@ -480,10 +563,12 @@ public class RMTxStore implements RMStore {
     protected void storeMessage(Identifier sid, RMMessage msg, boolean outbound)         
         throws IOException, SQLException {
         String id = sid.getValue();
-        BigInteger nr = msg.getMessageNumber();
+        long nr = msg.getMessageNumber();
         String to = msg.getTo();
-        LOG.log(Level.FINE, "Storing {0} message number {1} for sequence {2}, to = {3}",
-            new Object[] {outbound ? "outbound" : "inbound", nr, id, to});
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.log(Level.FINE, "Storing {0} message number {1} for sequence {2}, to = {3}",
+                    new Object[] {outbound ? "outbound" : "inbound", nr, id, to});
+        }
         PreparedStatement stmt = outbound ? createOutboundMessageStmt : createInboundMessageStmt;
         if (null == stmt) {
             stmt = connection.prepareStatement(MessageFormat.format(CREATE_MESSAGE_STMT_STR,
@@ -496,17 +581,14 @@ public class RMTxStore implements RMStore {
         }
         int i = 1;
         stmt.setString(i++, id);  
-        stmt.setBigDecimal(i++, new BigDecimal(nr));
+        stmt.setLong(i++, nr);
         stmt.setString(i++, to); 
-        byte[] bytes = msg.getContent();    
-        stmt.setBinaryStream(i++, new ByteArrayInputStream(bytes) {
-            public String toString() {
-                return IOUtils.newStringFromBytes(buf, 0, count);
-            }
-        }, bytes.length);
+        stmt.setBinaryStream(i++, msg.getInputStream(), msg.getSize());
         stmt.execute();
-        LOG.log(Level.FINE, "Successfully stored {0} message number {1} for sequence {2}",
-                new Object[] {outbound ? "outbound" : "inbound", nr, id});
+        if (LOG.isLoggable(Level.FINE)) {
+            LOG.log(Level.FINE, "Successfully stored {0} message number {1} for sequence {2}",
+                    new Object[] {outbound ? "outbound" : "inbound", nr, id});
+        }
         
     }
     
@@ -515,8 +597,8 @@ public class RMTxStore implements RMStore {
         if (null == updateSrcSequenceStmt) {
             updateSrcSequenceStmt = connection.prepareStatement(UPDATE_SRC_SEQUENCE_STMT_STR);
         }
-        updateSrcSequenceStmt.setBigDecimal(1, new BigDecimal(seq.getCurrentMessageNr())); 
-        updateSrcSequenceStmt.setBoolean(2, seq.isLastMessage()); 
+        updateSrcSequenceStmt.setLong(1, seq.getCurrentMessageNr()); 
+        updateSrcSequenceStmt.setString(2, seq.isLastMessage() ? "1" : "0"); 
         updateSrcSequenceStmt.setString(3, seq.getIdentifier().getValue());
         updateSrcSequenceStmt.execute();
     }
@@ -526,9 +608,8 @@ public class RMTxStore implements RMStore {
         if (null == updateDestSequenceStmt) {
             updateDestSequenceStmt = connection.prepareStatement(UPDATE_DEST_SEQUENCE_STMT_STR);
         }
-        BigInteger lastMessageNr = seq.getLastMessageNumber();
-        updateDestSequenceStmt.setBigDecimal(1, lastMessageNr == null ? null
-            : new BigDecimal(lastMessageNr)); 
+        long lastMessageNr = seq.getLastMessageNumber();
+        updateDestSequenceStmt.setLong(1, lastMessageNr); 
         InputStream is = PersistenceUtils.getInstance()
             .serialiseAcknowledgment(seq.getAcknowledgment());
         updateDestSequenceStmt.setBinaryStream(2, is, is.available()); 
@@ -679,9 +760,10 @@ public class RMTxStore implements RMStore {
         }
     }
 
-    private static boolean isTableExistsError(SQLException ex) {
-        return DERBY_TABLE_EXISTS_STATE.equals(ex.getSQLState())
-                || ORACLE_TABLE_EXISTS_CODE == ex.getErrorCode();
+    protected boolean isTableExistsError(SQLException ex) {
+        // we could be deriving the state/code from the driver url to avoid explicit setting of them
+        return (null != tableExistsState && tableExistsState.equals(ex.getSQLState()))
+                || tableExistsCode == ex.getErrorCode();
     }
 
 
