@@ -42,6 +42,7 @@ import org.apache.cxf.ws.security.policy.model.AlgorithmSuite;
 import org.apache.cxf.ws.security.policy.model.AsymmetricBinding;
 import org.apache.cxf.ws.security.policy.model.IssuedToken;
 import org.apache.cxf.ws.security.policy.model.RecipientToken;
+import org.apache.cxf.ws.security.policy.model.SamlToken;
 import org.apache.cxf.ws.security.policy.model.Token;
 import org.apache.cxf.ws.security.policy.model.TokenWrapper;
 import org.apache.cxf.ws.security.tokenstore.SecurityToken;
@@ -61,6 +62,7 @@ import org.apache.ws.security.message.WSSecEncryptedKey;
 import org.apache.ws.security.message.WSSecHeader;
 import org.apache.ws.security.message.WSSecSignature;
 import org.apache.ws.security.message.WSSecTimestamp;
+import org.apache.ws.security.saml.ext.AssertionWrapper;
 
 /**
  * 
@@ -117,6 +119,15 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
                             attached = true;
                         } 
                     }
+                } else if (initiatorToken instanceof SamlToken) {
+                    AssertionWrapper assertionWrapper = addSamlToken((SamlToken)initiatorToken);
+                    if (assertionWrapper != null) {
+                        if (includeToken(initiatorToken.getInclusion())) {
+                            addSupportingElement(assertionWrapper.toDOM(saaj.getSOAPPart()));
+                            storeAssertionAsSecurityToken(assertionWrapper);
+                        }
+                        policyAsserted(initiatorToken);
+                    }
                 }
             }
             
@@ -150,16 +161,19 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
             List<WSEncryptionPart> enc = getEncryptedParts();
             
             //Check for signature protection
-            if (abinding.isSignatureProtection() && mainSigId != null) {
-                WSEncryptionPart sigPart = new WSEncryptionPart(mainSigId, "Element");
-                sigPart.setElement(bottomUpElement);
-                enc.add(sigPart);
+            if (abinding.isSignatureProtection()) {
+                if (mainSigId != null) {
+                    WSEncryptionPart sigPart = new WSEncryptionPart(mainSigId, "Element");
+                    sigPart.setElement(bottomUpElement);
+                    enc.add(sigPart);
+                }
+                if (sigConfList != null && !sigConfList.isEmpty()) {
+                    enc.addAll(sigConfList);
+                }
             }
             
             if (isRequestor()) {
-                for (String id : encryptedTokensIdList) {
-                    enc.add(new WSEncryptionPart(id, "Element"));
-                }
+                enc.addAll(encryptedTokensList);
             }
 
             //Do encryption
@@ -201,6 +215,21 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
                         attached = true;
                     } 
                 }
+            } else if (initiatorToken instanceof SamlToken) {
+                try {
+                    AssertionWrapper assertionWrapper = addSamlToken((SamlToken)initiatorToken);
+                    if (assertionWrapper != null) {
+                        if (includeToken(initiatorToken.getInclusion())) {
+                            addSupportingElement(assertionWrapper.toDOM(saaj.getSOAPPart()));
+                            storeAssertionAsSecurityToken(assertionWrapper);
+                        }
+                        policyAsserted(initiatorToken);
+                    }
+                } catch (Exception e) {
+                    String reason = e.getMessage();
+                    LOG.log(Level.WARNING, "Encrypt before sign failed due to : " + reason);
+                    throw new Fault(e);
+                }
             }
         }
         
@@ -215,9 +244,9 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
             throw new Fault(ex);
         }
         
-        if (encryptionToken == null && encrParts.size() > 0) {
+        //if (encryptionToken == null && encrParts.size() > 0) {
             //REVISIT - no token to encrypt with  
-        }
+        //}
         
         if (encryptionToken != null && encrParts.size() > 0) {
             WSSecBase encrBase = doEncryption(wrapper, encrParts, true);
@@ -257,21 +286,25 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
             }
             
             // Check for signature protection
-            if (abinding.isSignatureProtection() && mainSigId != null) {
+            if (abinding.isSignatureProtection()) {
                 List<WSEncryptionPart> secondEncrParts = new ArrayList<WSEncryptionPart>();
 
                 // Now encrypt the signature using the above token
-                WSEncryptionPart sigPart = new WSEncryptionPart(mainSigId, "Element");
-                sigPart.setElement(bottomUpElement);
-                secondEncrParts.add(sigPart);
+                if (mainSigId != null) {
+                    WSEncryptionPart sigPart = new WSEncryptionPart(mainSigId, "Element");
+                    sigPart.setElement(bottomUpElement);
+                    secondEncrParts.add(sigPart);
+                }
+                
+                if (sigConfList != null && !sigConfList.isEmpty()) {
+                    secondEncrParts.addAll(sigConfList);
+                }
                 
                 if (isRequestor()) {
-                    for (String id : encryptedTokensIdList) {
-                        secondEncrParts.add(new WSEncryptionPart(id, "Element"));
-                    }
+                    secondEncrParts.addAll(encryptedTokensList);
                 }
 
-                if (encryptionToken.isDerivedKeys()) {
+                if (encryptionToken.isDerivedKeys() && !secondEncrParts.isEmpty()) {
                     try {
                         Element secondRefList 
                             = ((WSSecDKEncrypt)encrBase).encryptForExternalRef(null, secondEncrParts);
@@ -280,7 +313,7 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
                     } catch (WSSecurityException ex) {
                         throw new Fault(ex);
                     }
-                } else {
+                } else if (!secondEncrParts.isEmpty()) {
                     try {
                         // Encrypt, get hold of the ref list and add it
                         Element secondRefList = saaj.getSOAPPart()
@@ -406,6 +439,11 @@ public class AsymmetricBindingHandler extends AbstractBindingBuilder {
         sigToken = wrapper.getToken();
         sigParts.addAll(this.getSignedParts());
         if (sigParts.isEmpty()) {
+            // Add the BST to the security header if required
+            if (!attached && includeToken(sigToken.getInclusion())) {
+                WSSecSignature sig = getSignatureBuilder(wrapper, sigToken, attached, false);
+                sig.prependBSTElementToHeader(secHeader);
+            } 
             return;
         }
         if (sigToken.isDerivedKeys()) {
