@@ -75,9 +75,13 @@ import javax.xml.transform.dom.DOMSource;
 import org.apache.cxf.annotations.GZIP;
 import org.apache.cxf.common.util.ProxyHelper;
 import org.apache.cxf.helpers.XMLUtils;
+import org.apache.cxf.jaxrs.ext.MessageContext;
+import org.apache.cxf.jaxrs.ext.Nullable;
 import org.apache.cxf.jaxrs.ext.Oneway;
 import org.apache.cxf.jaxrs.ext.search.SearchCondition;
 import org.apache.cxf.jaxrs.ext.search.SearchContext;
+import org.apache.cxf.jaxrs.ext.xml.XMLInstruction;
+import org.apache.cxf.jaxrs.ext.xml.XSISchemaLocation;
 import org.apache.cxf.phase.PhaseInterceptorChain;
 
 @Path("/bookstore")
@@ -89,6 +93,9 @@ public class BookStore {
     private long bookId = 123;
     private long cdId = 123;
     
+    private String defaultName;
+    private long defaultId;
+    
     private String currentBookId;
     @PathParam("CDId")
     private String currentCdId;
@@ -112,6 +119,19 @@ public class BookStore {
     public void preDestroy() {
         //System.out.println("PreDestroy called");
     }
+
+    @GET
+    @Path("allCharsButA-B/:@!$&'()*+,;=-._~")
+    public Book getWithComplexPath() {
+        return new Book("Encoded Path", 125L);
+    }
+    
+    @GET
+    @Path("/default")
+    @Produces("application/xml")
+    public Book getDefaultBook() {
+        return new Book(defaultName, defaultId);
+    }
     
     @GET
     @Path("/books/colon/{a}:{b}:{c}")
@@ -195,9 +215,17 @@ public class BookStore {
         throw new BookNotFoundFault("Book Exception");
     }
     
+    @GET
+    @Path("propogateExceptionVar/{i}")
+    public Book propogateExceptionWithVar() throws BookNotFoundFault {
+        return null;
+    }
+    
     @GET
     @Path("name-in-query")
     @Produces("application/xml")
+    @XMLInstruction("<!DOCTYPE Something SYSTEM 'my.dtd'><?xmlstylesheet href='common.css'?>")
+    @XSISchemaLocation("book.xsd")
     public Book getBookFromQuery(@QueryParam("name") String name) {
         return new Book(name, 321L);
     }
@@ -224,6 +252,15 @@ public class BookStore {
         return books.containsKey(id);
     }
     
+    @GET
+    @Path("books/check/malformedmt/{id}")
+    @Produces("text/plain")
+    public Response checkBookMalformedMT(@PathParam("id") Long id,
+                                         @Context MessageContext mc) {
+        mc.put("org.apache.cxf.jaxrs.mediaTypeCheck.strict", false);
+        return Response.ok(books.containsKey(id)).type("text").build();
+    }
+    
     @POST
     @Path("books/check2")
     @Produces("text/plain")
@@ -293,6 +330,16 @@ public class BookStore {
         return bs;
     }
     
+    @POST
+    @Path("/collectionBook")
+    @Produces({"application/xml", "application/json" })
+    @Consumes({"application/xml", "application/json" })
+    public List<Book> postBookGetCollection(Book book) throws Exception {
+        List<Book> list = new ArrayList<Book>();
+        list.add(book);
+        return list;
+    }
+    
     @POST
     @Path("/collections3")
     @Produces({"application/xml", "application/json" })
@@ -362,6 +409,14 @@ public class BookStore {
         return doGetBook(s1 + s2);
     }
     
+    @GET
+    @Path("/segment/matrix-middle")
+    public Book getBookByMatrixParamsMiddle(@MatrixParam("first") String s1,
+                                      @MatrixParam("second") String s2) throws Exception {
+        
+        return doGetBook(s1 + s2);
+    }
+    
     @GET
     @Path("/segment/matrix-list")
     public Book getBookByMatrixListParams(@MatrixParam("first") List<String> list) throws Exception {
@@ -516,7 +571,7 @@ public class BookStore {
     }
     
     @GET
-    @Path("/books/{bookId}/")
+    @Path("/books/text/xml/{bookId}")
     @Produces("text/xml")
     public Book getBookTextXml(@PathParam("bookId") String id) throws BookNotFoundFault {
         return doGetBook(id);
@@ -638,6 +693,11 @@ public class BookStore {
         currentBookId = id;
     }
     
+    public void setDefaultNameAndId(String name, long id) {
+        defaultName = name;
+        defaultId = id;
+    }
+    
     @GET
     @Path("/books/{bookId}/")
     @Produces("application/json;q=0.9")
@@ -709,6 +769,17 @@ public class BookStore {
         }
     }
 
+    @POST
+    @Path("/books/null")
+    @Produces("application/xml")
+    @Consumes("application/xml")
+    public Book handleNullBook(@Nullable Book book) {
+        if (book != null) {
+            throw new WebApplicationException(400);
+        }
+        return new Book("Default Book", 222L);
+    }
+    
     @POST
     @Path("/books")
     @Produces("text/xml")
@@ -722,8 +793,6 @@ public class BookStore {
         }
         
         book.setId(bookId + 1);
-        books.put(book.getId(), book);
-
         return Response.ok(book).build();
     }
     
@@ -771,8 +840,7 @@ public class BookStore {
 
         Response r;
         if (b != null) {
-            books.put(book.getId(), book);
-            r = Response.ok().build();
+            r = Response.ok(book).build();
         } else {
             r = Response.notModified().build();
         }
@@ -789,8 +857,7 @@ public class BookStore {
         if (b == null) {
             Book newBook = new Book();
             newBook.setId(id);
-            books.put(newBook.getId(), newBook);
-            r = Response.ok().build();
+            r = Response.ok(newBook).build();
         } else {
             r = Response.notModified().build();
         }
@@ -813,8 +880,7 @@ public class BookStore {
 
         Response r;
         if (b != null) {
-            books.put(book.getId(), book);
-            r = Response.ok().build();
+            r = Response.ok(book).build();
         } else {
             r = Response.notModified().build();
         }
@@ -957,7 +1023,12 @@ public class BookStore {
         return new BookSubresourceImpl();
     }
     
-    final void init() {
+    public final String init() {
+        books.clear();
+        cds.clear();
+        bookId = 123;
+        cdId = 123;        
+        
         Book book = new Book();
         book.setId(bookId);
         book.setName("CXF in Action");
@@ -971,10 +1042,11 @@ public class BookStore {
         cd1.setId(++cdId);
         cd1.setName("BICYCLE RACE");
         cds.put(cd1.getId(), cd1);
+        return "OK";
     }
     
     @XmlJavaTypeAdapter(BookInfoAdapter2.class)
-    static interface BookInfoInterface {
+    interface BookInfoInterface {
         String getName();
         
         long getId();
