@@ -60,7 +60,6 @@ import org.apache.cxf.systest.jaxrs.BookStore.BookInfo;
 import org.apache.cxf.systest.jaxrs.BookStore.BookInfoInterface;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
 
-import org.junit.After;
 import org.junit.BeforeClass;
 import org.junit.Ignore;
 import org.junit.Test;
@@ -74,19 +73,6 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
         assertTrue("server did not launch correctly",
                    launchServer(BookServer.class));
     }
-    @After
-    public void resetBookServer() throws Exception {
-        new URL("http://localhost:" + PORT + "/bookstore/reset").openStream().close();
-    }
-    
-    @Test
-    public void testWithComplexPath() {
-        WebClient wc = 
-            WebClient.create("http://localhost:" + PORT + "/bookstore/allCharsButA-B/:@!$&'()*+,;=-._~");
-        wc.accept("application/xml");
-        Book book = wc.get(Book.class);
-        assertEquals("Encoded Path", book.getName());
-    }
     
     @Test
     public void testMalformedAcceptType() {
@@ -147,20 +133,6 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
         assertEquals(name, b.getName());
     }
     
-    @Test
-    public void testProcessingInstruction() throws Exception {
-        String base = "http://localhost:" + PORT;
-        String endpointAddress = base + "/bookstore/name-in-query"; 
-        WebClient wc = WebClient.create(endpointAddress);
-        String name = "Many        spaces";
-        wc.query("name", name);
-        String content = wc.get(String.class);
-        assertTrue(content.contains("<!DOCTYPE Something SYSTEM 'my.dtd'>"));
-        assertTrue(content.contains("<?xmlstylesheet href='" + base + "/common.css'?>"));
-        assertTrue(content.contains("xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""));
-        assertTrue(content.contains("xsi:schemaLocation=\"" + base + "/book.xsd\""));
-    }
-    
     @Test
     public void testGetBookWithColonMarks() throws Exception {
         
@@ -248,22 +220,6 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
         assertEquals(200, wc.getResponse().getStatus());
     }
     
-    @Test
-    public void testPostObjectGetCollection() throws Exception {
-        
-        String endpointAddress =
-            "http://localhost:" + PORT + "/bookstore/collectionBook"; 
-        WebClient wc = WebClient.create(endpointAddress);
-        wc.accept("application/xml").type("application/xml");
-        Book b1 = new Book("Book", 666L);
-        List<Book> books = new ArrayList<Book>(wc.postObjectGetCollection(b1, Book.class));
-        assertNotNull(books);
-        assertEquals(1, books.size());
-        Book b = books.get(0);
-        assertEquals(666L, b.getId());
-        assertEquals("Book", b.getName());
-    }
-    
     @Test
     public void testGetBookResponseAndETag() throws Exception {
         
@@ -1008,33 +964,6 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
         assertEquals(444L, book.getId());
     }
     
-    @Test
-    public void testFormattedJSON() {
-        WebClient wc = WebClient.create("http://localhost:" + PORT + "/bookstore/books/123");
-        wc.accept("application/json");
-        String response = wc.get(String.class);
-        // {"Book":{"id":123,"name":"CXF in Action"}}
-        
-        assertTrue(response.startsWith("{"));
-        assertTrue(response.endsWith("}"));
-        assertTrue(response.contains("\"Book\":{"));
-        assertTrue(response.indexOf("\"Book\":{") == 1);
-        
-        wc.query("_format", "");
-        response = wc.get(String.class);
-        //{
-        //    "Book":{
-        //      "id":123,
-        //      "name":"CXF in Action"
-        //    }
-        //}
-        assertTrue(response.startsWith("{"));
-        assertTrue(response.endsWith("}"));
-        assertTrue(response.contains("\"Book\":{"));
-        assertFalse(response.indexOf("\"Book\":{") == 1);
-        
-    }
-    
     @Test
     public void testGetBook123() throws Exception {
         getAndCompareAsStrings("http://localhost:" + PORT + "/bookstore/books/123",
@@ -1109,14 +1038,6 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
                                "application/xml", 200);
     }
     
-    @Test
-    public void testGetBookByMatrixParametersInTheMiddle() throws Exception {
-        getAndCompareAsStrings(
-            "http://localhost:" + PORT + "/bookstore/segment;first=12;second=3/matrix-middle",
-            "resources/expected_get_book123.txt",
-            "application/xml", 200);
-    }
-    
     @Test
     public void testGetBookByHeader() throws Exception {
         getAndCompareAsStrings("http://localhost:" + PORT + "/bookstore/bookheaders",
@@ -1336,19 +1257,6 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
         }
     }
     
-    @Test
-    public void testAddBookEmptyContent() throws Exception {
-        Response r = WebClient.create("http://localhost:" + PORT + "/bookstore/books").post(null);
-        assertEquals(400, r.getStatus());
-    }
-    
-    @Test
-    public void testAddBookEmptyContentWithNullable() throws Exception {
-        Book defaultBook = 
-            WebClient.create("http://localhost:" + PORT + "/bookstore/books/null").post(null, Book.class);
-        assertEquals("Default Book", defaultBook.getName());
-    }
-    
     @Test
     public void testAddBook() throws Exception {
         doAddBook("http://localhost:" + PORT + "/bookstore/books");               
@@ -1675,9 +1583,9 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
     public void testUriInfoMatchedResources() throws Exception {
         getAndCompare("http://localhost:" + PORT + "/bookstore/"
                       + "booksubresource/123/chapters/sub/1/matched-resources", 
-                      "[class org.apache.cxf.systest.jaxrs.Chapter, " 
+                      "[class org.apache.cxf.systest.jaxrs.BookStore, " 
                       + "class org.apache.cxf.systest.jaxrs.Book, "
-                      + "class org.apache.cxf.systest.jaxrs.BookStore]", 
+                      + "class org.apache.cxf.systest.jaxrs.Chapter]", 
                       "text/plain", "text/plain", 200);
     }
     
@@ -1685,17 +1593,17 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
     public void testUriInfoMatchedResourcesWithObject() throws Exception {
         getAndCompare("http://localhost:" + PORT + "/bookstore/"
                       + "booksubresource/123/chaptersobject/sub/1/matched-resources", 
-                      "[class org.apache.cxf.systest.jaxrs.Chapter, " 
+                      "[class org.apache.cxf.systest.jaxrs.BookStore, " 
                       + "class org.apache.cxf.systest.jaxrs.Book, "
-                      + "class org.apache.cxf.systest.jaxrs.BookStore]", 
+                      + "class org.apache.cxf.systest.jaxrs.Chapter]", 
                       "text/plain", "text/plain", 200);
     }
 
     @Test
     public void testUriInfoMatchedUrisDecode() throws Exception {
-        String expected = "[/bookstore/booksubresource/123/chapters/sub/1/matched!uris, "
+        String expected = "[/bookstore/booksubresource/123/, "
                           + "/bookstore/booksubresource/123/chapters/sub/1/, "
-                          + "/bookstore/booksubresource/123/]";
+                          + "/bookstore/booksubresource/123/chapters/sub/1/matched!uris]";
         getAndCompare("http://localhost:" + PORT + "/bookstore/"
                       + "booksubresource/123/chapters/sub/1/matched%21uris?decode=true", 
                       expected, "text/plain", "text/plain", 200);
@@ -1704,9 +1612,9 @@ public class JAXRSClientServerBookTest extends AbstractBusClientServerTestBase {
     @Test
     public void testUriInfoMatchedUrisNoDecode() throws Exception {
         //note '%21' instead of '!'
-        String expected = "[/bookstore/booksubresource/123/chapters/sub/1/matched%21uris, "
+        String expected = "[/bookstore/booksubresource/123/, "
             + "/bookstore/booksubresource/123/chapters/sub/1/, "
-            + "/bookstore/booksubresource/123/]";
+            + "/bookstore/booksubresource/123/chapters/sub/1/matched%21uris]";
         getAndCompare("http://localhost:" + PORT + "/bookstore/"
                       + "booksubresource/123/chapters/sub/1/matched%21uris?decode=false", 
                       expected,
