@@ -308,6 +308,45 @@ public class JAXRSClientServerSpringBookTest extends AbstractBusClientServerTest
         
     }
     
+    @Test
+    public void testGetBookXsiType() throws Exception {
+        String address = "http://localhost:" + PORT + "/the/thebooksxsi/bookstore/books/xsitype";
+        WebClient wc = WebClient.create(address);
+        wc.accept("application/xml");
+        Book book = wc.get(Book.class);
+        assertEquals("SuperBook", book.getName());
+        
+    }
+    
+    @Test
+    public void testPostBookXsiType() throws Exception {
+        String address = "http://localhost:" + PORT + "/the/thebooksxsi/bookstore/books/xsitype";
+        JAXBElementProvider provider = new JAXBElementProvider();
+        provider.setExtraClass(new Class[]{SuperBook.class});
+        provider.setJaxbElementClassNames(Collections.singletonList(Book.class.getName()));
+        WebClient wc = WebClient.create(address, Collections.singletonList(provider));
+        wc.accept("application/xml");
+        wc.type("application/xml");
+        SuperBook book = new SuperBook("SuperBook2", 999L);
+        Book book2 = wc.invoke("POST", book, Book.class, Book.class);
+        assertEquals("SuperBook2", book2.getName());
+        
+    }
+    
+    @Test
+    public void testPostBookXsiTypeProxy() throws Exception {
+        String address = "http://localhost:" + PORT + "/the/thebooksxsi/bookstore";
+        JAXBElementProvider provider = new JAXBElementProvider();
+        provider.setExtraClass(new Class[]{SuperBook.class});
+        provider.setJaxbElementClassNames(Collections.singletonList(Book.class.getName()));
+        BookStoreSpring bookStore = JAXRSClientFactory.create(address, BookStoreSpring.class, 
+                                                              Collections.singletonList(provider));
+        SuperBook book = new SuperBook("SuperBook2", 999L);
+        Book book2 = bookStore.postGetBookXsiType(book);
+        assertEquals("SuperBook2", book2.getName());
+        
+    }
+    
     @Test
     public void testGetBookWithEncodedQueryValue() throws Exception {
         String endpointAddress =
@@ -574,6 +613,18 @@ public class JAXRSClientServerSpringBookTest extends AbstractBusClientServerTest
                "resources/expected_get_book123.txt");
     }
     
+    @Test
+    public void testAddInvalidBookDuplicateElementJson() throws Exception {
+        WebClient wc = WebClient.create("http://localhost:" + PORT + "/the/bookstore/books/convert");
+        wc.type("application/json");
+        InputStream is = getClass().getResourceAsStream("resources/add_book2json_duplicate.txt");
+        assertNotNull(is);
+        Response r = wc.post(is);
+        assertEquals(400, r.getStatus());
+        String content = IOUtils.readStringFromStream((InputStream)r.getEntity());
+        assertTrue(content.contains("Invalid content was found starting with element 'id'"));
+    }
+    
     private void doPost(String endpointAddress, int expectedStatus, String contentType,
                         String inResource, String expectedResource) throws Exception {
         
