@@ -134,6 +134,12 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         doAddFormBook(address, "attachmentFormJsonFiles", 200);               
     }
     
+    @Test
+    public void testBookJSONFormTwoFilesMixUp() throws Exception {
+        String address = "http://localhost:" + PORT + "/bookstore/books/filesform/mixup";
+        doAddFormBook(address, "attachmentFormJsonFiles", 200);               
+    }
+    
     @Test
     public void testBookJSONFormOneFile() throws Exception {
         String address = "http://localhost:" + PORT + "/bookstore/books/fileform";
@@ -234,13 +240,21 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
     public void testAddBookAsJAXBJSONProxy() throws Exception {
         MultipartStore store = 
             JAXRSClientFactory.create("http://localhost:" + PORT, MultipartStore.class);
-        
         Book b = store.addBookJaxbJsonWithConsumes(new Book2("CXF in Action", 1L), 
                                            new Book("CXF in Action - 2", 2L));
         assertEquals(124L, b.getId());
         assertEquals("CXF in Action - 2", b.getName());
     }
     
+    @Test
+    public void testUseProxyToAddBookAndSimpleParts() throws Exception {
+        MultipartStore store = 
+            JAXRSClientFactory.create("http://localhost:" + PORT, MultipartStore.class);
+        Book b = store.testAddBookAndSimpleParts(new Book("CXF in Action", 124L), "1", "2");
+        assertEquals(124L, b.getId());
+        assertEquals("CXF in Action - 12", b.getName());
+    }
+    
     @Test
     public void testAddBookAsJAXBOnlyProxy() throws Exception {
         MultipartStore store = 
@@ -327,6 +341,7 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         conduit.getClient().setConnectionTimeout(1000000);
         
         client.type("multipart/related").accept("multipart/related");
+        
         XopType xop = new XopType();
         xop.setName("xopName");
         InputStream is = 
@@ -413,7 +428,6 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         String address = "http://localhost:" + PORT;
         MultipartStore client = JAXRSClientFactory.create(address, MultipartStore.class);
         
-        
         Map<String, Book> map = client.getBookJaxbJson();
         List<Book> result = new ArrayList<Book>(map.values());
         Book jaxb = result.get(0);
@@ -422,6 +436,31 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         Book json = result.get(1);
         assertEquals("json", json.getName());
         assertEquals(2L, json.getId());
+        
+        String contentType = 
+            WebClient.client(client).getResponse().getMetadata().getFirst("Content-Type").toString();
+        MediaType mt = MediaType.valueOf(contentType);
+        assertEquals("multipart", mt.getType());
+        assertEquals("mixed", mt.getSubtype());
+    }
+    
+    @Test
+    public void testGetBookJsonProxy() throws Exception {
+        String address = "http://localhost:" + PORT;
+        MultipartStore client = JAXRSClientFactory.create(address, MultipartStore.class);
+        
+        Map<String, Book> map = client.getBookJson();
+        List<Book> result = new ArrayList<Book>(map.values());
+        assertEquals(1, result.size());
+        Book json = result.get(0);
+        assertEquals("json", json.getName());
+        assertEquals(1L, json.getId());
+        
+        String contentType = 
+            WebClient.client(client).getResponse().getMetadata().getFirst("Content-Type").toString();
+        MediaType mt = MediaType.valueOf(contentType);
+        assertEquals("multipart", mt.getType());
+        assertEquals("mixed", mt.getSubtype());
     }
     
     @Test
