@@ -155,15 +155,6 @@ public class MultipartStore {
         }
     }
     
-    @POST
-    @Path("/books/testnullpartFormParam")
-    @Consumes("multipart/form-data")
-    @Produces("text/plain")
-    public String testNullPartFormParam(@FormParam(value = "someid") String value) {
-        return testNullPart(value);
-    }
-    
-    
     @POST
     @Path("/books/jaxbjsonimage")
     @Consumes("multipart/mixed")
@@ -352,32 +343,10 @@ public class MultipartStore {
         return addBooks(books);
     }
     
-    @POST
-    @Path("/books/jaxbjsonconsumes")
-    @Consumes("multipart/related")
-    @Produces("text/xml")
-    public Book addBookJaxbJsonWithConsumes(
-        @Multipart(value = "rootPart", type = "text/xml") Book2 b1,
-        @Multipart(value = "book2", type = "application/json") Book b2) throws Exception {
-        return addBookJaxbJson(b1, b2);    
-    }
-    
-    @POST
-    @Path("/books/jaxbonly")
-    @Consumes("multipart/related")
-    @Produces("text/xml")
-    public Book2 addBookJaxbOnlyWithConsumes(
-        @Multipart(value = "rootPart", type = "text/xml") Book2 b1) throws Exception {
-        if (!"CXF in Action".equals(b1.getName())) {
-            throw new WebApplicationException();
-        }
-        return b1;    
-    }
-    
     @POST
     @Path("/books/jaxbjson")
     @Produces("text/xml")
-    public Book addBookJaxbJson(
+    public Response addBookJaxbJson(
         @Multipart(value = "rootPart", type = "text/xml") Book2 b1,
         @Multipart(value = "book2", type = "application/json") Book b2) 
         throws Exception {
@@ -386,7 +355,7 @@ public class MultipartStore {
             throw new WebApplicationException();
         }
         b2.setId(124);
-        return b2;
+        return Response.ok(b2).build();
     }
     
     @POST
