@@ -22,6 +22,7 @@ package org.apache.cxf.systest.jaxws;
 import java.io.InputStream;
 import java.lang.reflect.Field;
 import java.lang.reflect.UndeclaredThrowableException;
+import java.math.BigInteger;
 import java.net.HttpURLConnection;
 import java.net.URL;
 import java.util.ArrayList;
@@ -32,6 +33,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import javax.xml.datatype.DatatypeFactory;
+import javax.xml.datatype.XMLGregorianCalendar;
 import javax.xml.namespace.QName;
 import javax.xml.ws.BindingProvider;
 import javax.xml.ws.Holder;
@@ -51,9 +54,11 @@ import org.apache.cxf.anonymous_complex_type.SplitName;
 import org.apache.cxf.anonymous_complex_type.SplitNameResponse.Names;
 import org.apache.cxf.binding.soap.Soap11;
 import org.apache.cxf.binding.soap.SoapFault;
+import org.apache.cxf.common.WSDLConstants;
 import org.apache.cxf.common.util.ASMHelper;
 import org.apache.cxf.endpoint.Client;
 import org.apache.cxf.frontend.ClientProxyFactoryBean;
+import org.apache.cxf.helpers.IOUtils;
 import org.apache.cxf.helpers.XMLUtils;
 import org.apache.cxf.helpers.XPathUtils;
 import org.apache.cxf.jaxb_element_test.JaxbElementTest;
@@ -62,6 +67,7 @@ import org.apache.cxf.jaxws.endpoint.dynamic.JaxWsDynamicClientFactory;
 import org.apache.cxf.ordered_param_holder.ComplexStruct;
 import org.apache.cxf.ordered_param_holder.OrderedParamHolder;
 import org.apache.cxf.ordered_param_holder.OrderedParamHolder_Service;
+import org.apache.cxf.systest.jaxws.DocLitBareCodeFirstService.GMonthTest;
 import org.apache.cxf.systest.jaxws.DocLitWrappedCodeFirstService.CXF2411Result;
 import org.apache.cxf.systest.jaxws.DocLitWrappedCodeFirstService.CXF2411SubClass;
 import org.apache.cxf.systest.jaxws.DocLitWrappedCodeFirstService.Foo;
@@ -75,13 +81,106 @@ import org.junit.BeforeClass;
 import org.junit.Test;
 
 public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
+    static final String PORT = allocatePort(ServerMisc.class);
 
 
     @BeforeClass
     public static void startServers() throws Exception {
         assertTrue("server did not launch correctly", launchServer(ServerMisc.class));
     }
-
+    @Test
+    public void testCXF3170() throws Exception {
+        URL url = new URL(ServerMisc.DOCLITBARE_CODEFIRST_URL + "/foo");
+        HttpURLConnection con = (HttpURLConnection)url.openConnection();
+        con.getResponseCode();
+        String  str = IOUtils.readStringFromStream(con.getErrorStream());
+        assertTrue(str.contains("/foo"));  //No such operation
+    }
+    @Test
+    public void testWSDLDocs() throws Exception {
+        Map<String, String> ns = new HashMap<String, String>();
+        ns.put("wsdl", WSDLConstants.NS_WSDL11);
+        XPathUtils xpu = new XPathUtils(ns);
+        Document wsdl = XMLUtils.parse(this.getHttpConnection(ServerMisc.DOCLIT_CODEFIRST_URL + "?wsdl")
+                                          .getInputStream());
+        //XMLUtils.printDOM(wsdl.getDocumentElement());
+        assertEquals("DocLitWrappedCodeFirstService impl",
+                     xpu.getValue("/wsdl:definitions/wsdl:service/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("DocLitWrappedCodeFirstService interface",
+                     xpu.getValue("/wsdl:definitions/wsdl:portType/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("DocLitWrappedCodeFirstService top level doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("DocLitWrappedCodeFirstService binding doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:binding/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("DocLitWrappedCodeFirstService service/port doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:service/wsdl:port/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:portType/wsdl:operation[@name='multiInOut']"
+                                  + "/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut Input doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:portType/wsdl:operation[@name='multiInOut']"
+                                  + "/wsdl:input/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut Output doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:portType/wsdl:operation[@name='multiInOut']"
+                                  + "/wsdl:output/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut InputMessage doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:message[@name='multiInOut']"
+                                  + "/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut OutputMessage doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:message[@name='multiInOutResponse']"
+                                  + "/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut binding doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:binding/wsdl:operation[@name='multiInOut']"
+                                  + "/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut binding Input doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:binding/wsdl:operation[@name='multiInOut']"
+                                  + "/wsdl:input/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("multiInOut binding Output doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:binding/wsdl:operation[@name='multiInOut']"
+                                  + "/wsdl:output/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("fault binding doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:binding/wsdl:operation[@name='throwException']"
+                                  + "/wsdl:fault/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("fault porttype doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:portType/wsdl:operation[@name='throwException']"
+                                  + "/wsdl:fault/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+        assertEquals("fault message doc",
+                     xpu.getValue("/wsdl:definitions/wsdl:message[@name='CustomException']"
+                                  + "/wsdl:documentation",
+                                  wsdl.getDocumentElement(),
+                                  XPathConstants.STRING));
+    }
+    
     @Test
     public void testDocLitBare() throws Exception {
         QName portName = new QName("http://cxf.apache.org/systest/jaxws/DocLitBareCodeFirstService", 
@@ -97,12 +196,20 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
                                   DocLitBareCodeFirstService.class);
         DocLitBareCodeFirstService.GreetMeRequest req = 
             new DocLitBareCodeFirstService.GreetMeRequest();
-        req.setName("Foo");
-        DocLitBareCodeFirstService.GreetMeResponse resp =
-            port.greetMe(req);
+        DocLitBareCodeFirstService.GreetMeResponse resp;
+        BigInteger i[];
         
+        req.setName("Foo");
+        resp = port.greetMe(req);
         assertEquals(req.getName(), resp.getName());
         
+        i = port.sayTest(new DocLitBareCodeFirstService.SayTestRequest("Dan"));
+        assertEquals(4, i.length);
+        assertEquals(0, i[0].intValue());
+        assertEquals(1, i[1].intValue());
+        assertEquals(2, i[2].intValue());
+        assertEquals(3, i[3].intValue());
+        
         //try with wsdl
         service = Service.create(new URL(ServerMisc.DOCLITBARE_CODEFIRST_URL + "?wsdl"),
                                          servName);
@@ -126,6 +233,14 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
         } catch (SOAPFaultException ex) {
             assertFalse(ex.getFault().hasDetail());
         }
+        
+        GMonthTest gm = new GMonthTest();
+        XMLGregorianCalendar dt = DatatypeFactory.newInstance().newXMLGregorianCalendarDate(2010, 11, 16, 0);
+        gm.setValue(dt);
+        GMonthTest gm2 = port.echoGMonthTest(gm);
+        
+        assertEquals(gm.getValue().getMonth(), gm2.getValue().getMonth());
+        
     } 
     
 
@@ -137,7 +252,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
         QName portName = new QName("http://cxf.apache.org/anonymous_complex_type/",
             "anonymous_complex_typeSOAP");
         AnonymousComplexType act = actService.getPort(portName, AnonymousComplexType.class);
-
+        updateAddressPort(act, PORT);
         try {
             Names reply = act.splitName("Tom Li");
             assertNotNull("no response received from service", reply);
@@ -156,6 +271,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
         QName portName = new QName("http://cxf.apache.org/anonymous_complex_type/",
             "anonymous_complex_typeSOAP");
         AnonymousComplexType act = actService.getPort(portName, AnonymousComplexType.class);
+        updateAddressPort(act, PORT);
 
         try {
             SplitName name = new SplitName();
@@ -177,6 +293,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
         JaxbElementTest_Service service = new JaxbElementTest_Service();
         assertNotNull(service);
         JaxbElementTest port = service.getPort(JaxbElementTest.class);
+        updateAddressPort(port, PORT);
 
         try {
 
@@ -197,6 +314,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
     public void testOrderedParamHolder() throws Exception {
         OrderedParamHolder_Service service = new OrderedParamHolder_Service();
         OrderedParamHolder port = service.getOrderedParamHolderSOAP();
+        updateAddressPort(port, PORT);
         
         try {
             Holder<ComplexStruct> part3 = new Holder<ComplexStruct>();
@@ -274,6 +392,21 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
                                                              DocLitWrappedCodeFirstService.class);
         runDocLitTest(port);
     }
+    
+    @Test
+    public void testWrappedHolderOutNull() throws Exception {
+        // this test to verify CXF-3836 works
+        QName portName = new QName("http://cxf.apache.org/systest/jaxws/DocLitWrappedCodeFirstService",
+                                   "DocLitWrappedCodeFirstServicePort");
+        QName servName = new QName("http://cxf.apache.org/systest/jaxws/DocLitWrappedCodeFirstService",
+                                   "DocLitWrappedCodeFirstService");
+
+        Service service = Service.create(new URL(ServerMisc.DOCLIT_CODEFIRST_URL + "?wsdl"), servName);
+        DocLitWrappedCodeFirstService port = service.getPort(portName, DocLitWrappedCodeFirstService.class);
+        Holder<Boolean> created = new Holder<Boolean>();
+        port.singleInOut(created);
+        assertEquals(created.value, Boolean.FALSE);
+    }
 
     private void setASM(boolean b) throws Exception {
         Field f = ASMHelper.class.getDeclaredField("oldASM");
@@ -643,6 +776,7 @@ public class ClientServerMiscTest extends AbstractBusClientServerTestBase {
     public void testInheritedTypesInOtherPackage() throws Exception {
         InheritService serv = new InheritService();
         Inherit port = serv.getInheritPort();
+        updateAddressPort(port, PORT);
         ObjectInfo obj = port.getObject(0);
         assertNotNull(obj);
         assertNotNull(obj.getBaseObject());
