@@ -23,6 +23,7 @@ package org.apache.cxf.systest.http;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
+import java.net.MalformedURLException;
 import java.net.URL;
 import java.security.GeneralSecurityException;
 import java.security.KeyStore;
@@ -30,6 +31,9 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 import java.util.TreeMap;
+import java.util.logging.Level;
+import java.util.logging.LogManager;
+import java.util.logging.Logger;
 
 import javax.net.ssl.KeyManager;
 import javax.net.ssl.KeyManagerFactory;
@@ -52,10 +56,11 @@ import org.apache.cxf.message.Message;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
 
 import org.apache.cxf.transport.http.HTTPConduit;
-import org.apache.cxf.transport.http.HttpAuthSupplier;
 import org.apache.cxf.transport.http.MessageTrustDecider;
 import org.apache.cxf.transport.http.URLConnectionInfo;
 import org.apache.cxf.transport.http.UntrustedURLConnectionIOException;
+import org.apache.cxf.transport.http.auth.HttpAuthHeader;
+import org.apache.cxf.transport.http.auth.HttpAuthSupplier;
 
 import org.apache.cxf.transport.https.HttpsURLConnectionInfo;
 
@@ -266,11 +271,8 @@ public class HTTPConduitTest extends AbstractBusClientServerTestBase {
         
         return fac.getTrustManagers();
     }
-    
-    
-    @Test
-    public void testBasicConnection() throws Exception {
-        startServer("Mortimer");
+
+    private Greeter getMortimerGreeter() throws MalformedURLException {
         URL wsdl = getClass().getResource("resources/greeting.wsdl");
         assertNotNull("WSDL is null", wsdl);
 
@@ -280,12 +282,34 @@ public class HTTPConduitTest extends AbstractBusClientServerTestBase {
         Greeter mortimer = service.getPort(mortimerQ, Greeter.class);
         assertNotNull("Port is null", mortimer);
         updateAddressPort(mortimer, PORT0);
+        return mortimer;
+    }
+
+    @Test
+    public void testBasicConnection() throws Exception {
+        startServer("Mortimer");
+        Greeter mortimer = getMortimerGreeter();
 
         String answer = mortimer.sayHi();
         assertTrue("Unexpected answer: " + answer, 
                 "Bonjour from Mortimer".equals(answer));
     }
 
+    @Test
+    public void testLogLevelIssueCXF3466() throws Exception {
+        startServer("Mortimer");
+        Greeter mortimer = getMortimerGreeter();
+        Logger rootLogger = LogManager.getLogManager().getLogger("");
+        Level oldLevel = rootLogger.getLevel();
+        rootLogger.setLevel(Level.FINE);
+        try {
+            // Will throw exception Stream is closed if bug is present
+            mortimer.sayHi();
+        } finally {
+            rootLogger.setLevel(oldLevel);
+        }
+    }
+
     /**
      * This methods tests that a conduit that is not configured
      * to follow redirects will not. The default is not to 
@@ -742,7 +766,7 @@ public class HTTPConduitTest extends AbstractBusClientServerTestBase {
         
     }
 
-    public class MyBasicAuthSupplier extends HttpAuthSupplier {
+    public class MyBasicAuthSupplier implements HttpAuthSupplier {
 
         String realm;
         String user;
@@ -759,27 +783,18 @@ public class HTTPConduitTest extends AbstractBusClientServerTestBase {
             user  = u;
             pass  = p;
         }
-        @Override
-        public String getPreemptiveAuthorization(
-                HTTPConduit  conduit,
-                URL     currentURL,
-                Message message
-        ) {
-            return null;
-        }
 
         /**
          * If we don't have the realm set, then we loop
          * through the realms.
          */
-        @Override
-        public String getAuthorizationForRealm(
-                HTTPConduit  conduit, 
+        public String getAuthorization(
+                AuthorizationPolicy authPolicy,
                 URL     currentURL,
-                Message message, 
-                String  reqestedRealm,
+                Message message,
                 String fullHeader
         ) {
+            String reqestedRealm = new HttpAuthHeader(fullHeader).getRealm();
             if (realm != null && realm.equals(reqestedRealm)) {
                 return createUserPass(user, pass);
             }
@@ -804,6 +819,10 @@ public class HTTPConduitTest extends AbstractBusClientServerTestBase {
             return "Basic " + token;
         }
 
+        public boolean requiresRequestCaching() {
+            return false;
+        }
+
     }
 
     /**
