@@ -26,11 +26,11 @@ import javax.xml.ws.Service;
 
 import org.apache.cxf.Bus;
 import org.apache.cxf.bus.spring.SpringBusFactory;
-import org.apache.cxf.endpoint.Client;
-import org.apache.cxf.frontend.ClientProxy;
 import org.apache.cxf.systest.ws.ut.server.Server;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
+
 import org.example.contract.doubleit.DoubleItPortType;
+
 import org.junit.BeforeClass;
 
 /**
@@ -189,65 +189,4 @@ public class UsernameTokenTest extends AbstractBusClientServerTestBase {
         utPort.doubleIt(25);
     }
     
-    @org.junit.Test
-    public void testNoUsernameToken() throws Exception {
-
-        SpringBusFactory bf = new SpringBusFactory();
-        URL busFile = UsernameTokenTest.class.getResource("client/client.xml");
-
-        Bus bus = bf.createBus(busFile.toString());
-        SpringBusFactory.setDefaultBus(bus);
-        SpringBusFactory.setThreadDefaultBus(bus);
-
-        URL wsdl = UsernameTokenTest.class.getResource("DoubleItUt.wsdl");
-        Service service = Service.create(wsdl, SERVICE_QNAME);
-        QName portQName = new QName(NAMESPACE, "DoubleItInlinePolicyPort");
-        DoubleItPortType utPort = 
-                service.getPort(portQName, DoubleItPortType.class);
-        updateAddressPort(utPort, PORT);
-        
-        try {
-            utPort.doubleIt(25);
-            fail("Failure expected on no UsernameToken");
-        } catch (javax.xml.ws.soap.SOAPFaultException ex) {
-            String error = "The received token does not match the token inclusion requirement";
-            assertTrue(ex.getMessage().contains(error));
-        }
-    }
-    
-    @org.junit.Test
-    public void testPasswordHashedReplay() throws Exception {
-
-        SpringBusFactory bf = new SpringBusFactory();
-        URL busFile = UsernameTokenTest.class.getResource("client/client.xml");
-
-        Bus bus = bf.createBus(busFile.toString());
-        SpringBusFactory.setDefaultBus(bus);
-        SpringBusFactory.setThreadDefaultBus(bus);
-
-        URL wsdl = UsernameTokenTest.class.getResource("DoubleItUt.wsdl");
-        Service service = Service.create(wsdl, SERVICE_QNAME);
-        
-        QName portQName = new QName(NAMESPACE, "DoubleItHashedPort");
-        DoubleItPortType utPort = 
-                service.getPort(portQName, DoubleItPortType.class);
-        updateAddressPort(utPort, PORT);
-        
-        Client cxfClient = ClientProxy.getClient(utPort);
-        SecurityHeaderCacheInterceptor cacheInterceptor =
-            new SecurityHeaderCacheInterceptor();
-        cxfClient.getOutInterceptors().add(cacheInterceptor);
-        
-        // Make two invocations with the same UsernameToken
-        utPort.doubleIt(25);
-        try {
-            utPort.doubleIt(25);
-            fail("Failure expected on a replayed UsernameToken");
-        } catch (javax.xml.ws.soap.SOAPFaultException ex) {
-            String error = "A replay attack has been detected";
-            assertTrue(ex.getMessage().contains(error));
-        }
-        
-    }
-    
 }
