@@ -186,8 +186,6 @@ public abstract class MAPTestBase extends AbstractClientServerTestBase implement
     }
 
     @Test
-    //@org.junit.Ignore("randomly fails quite often, but not in the "
-    //                    + " debugger so not sure what is going on yet")
     public void testExplicitMAPs() throws Exception {
         try {
             String msgId = "urn:uuid:12345-" + Math.random();
@@ -259,7 +257,6 @@ public abstract class MAPTestBase extends AbstractClientServerTestBase implement
     
     
     @Test
-    //@org.junit.Ignore("Random failure on Linux")
     public void testApplicationFault() throws Exception {
         try {
             greeter.testDocLitFault("BadRecordLitFault");
@@ -372,7 +369,8 @@ public abstract class MAPTestBase extends AbstractClientServerTestBase implement
      */
     protected static String verifyHeaders(List<String> wsaHeaders,
                                           boolean partial,
-                                          boolean requestLeg) {
+                                          boolean requestLeg,
+                                          boolean replyToRequired) {
         //System.out.println("verifying headers: " + wsaHeaders);
         String ret = null;
         if (!wsaHeaders.contains(Names.WSA_MESSAGEID_NAME)) {
@@ -382,8 +380,9 @@ public abstract class MAPTestBase extends AbstractClientServerTestBase implement
             ret = "expected To header";
         }
        
-        if (!(wsaHeaders.contains(Names.WSA_REPLYTO_NAME)
-              || wsaHeaders.contains(Names.WSA_RELATESTO_NAME))) {
+        if (replyToRequired 
+            && !(wsaHeaders.contains(Names.WSA_REPLYTO_NAME)
+                || wsaHeaders.contains(Names.WSA_RELATESTO_NAME))) {
             ret = "expected ReplyTo or RelatesTo header";
         }
         /*
